pub struct ClientConfig { /* private fields */ }Expand description
Client-side TLS configuration wrapper.
Implementations
Sourceimpl ClientConfig
impl ClientConfig
Sourcepub fn with_native_roots() -> Result<Self>
pub fn with_native_roots() -> Result<Self>
Builds a client config from native platform root certificates.
Sourcepub fn dangerous_insecure_no_verify_for_testing() -> Self
pub fn dangerous_insecure_no_verify_for_testing() -> Self
Builds an insecure testing-only client config that skips certificate verification.
Sourcepub fn with_custom_roots(certs: Vec<CertificateDer<'static>>) -> Result<Self>
pub fn with_custom_roots(certs: Vec<CertificateDer<'static>>) -> Result<Self>
Creates a client config that trusts one or more custom root certificates.